cgroup: uninline cgroup_has_css_refs()
PATCH 1/1 cgroup: uninline cgroup_has_css_refs()
It's not small enough, and has 2 call sites.
text data bss dec hex filename 12813 1676 4832 19321 4b79 cgroup.o.orig 12775 1676 4832 19283 4b53 cgroup.o
Signed-off-by Li Zefan <[email protected]>
--- kernel/cgroup.c | 2 +- 1 files changed, 1 insertions(+), 1 deletions(-)
kernel/cgroup.c +1 -1
@@ -2368,7 +2368,7 @@ static int cgroup_mkdir(struct inode *dir, struct dentry *dentry, int mode)return cgroup_create (c_parent, dentry, mode |S_IFDIR ); } -static inline int cgroup_has_css_refs (struct cgroup *cgrp) +static int cgroup_has_css_refs (struct cgroup *cgrp) {/* Check the reference count on each subsystem. Since we * already established that there are no tasks in the
Signature · 1 line
1.5.4.rc3
A message that is not in the archive (sent off-list or not yet received): [email protected]
Quoted 7 lines · Li Zefan
It's not small enough, and has 2 call sites.
text data bss dec hex filename 12813 1676 4832 19321 4b79 cgroup.o.orig 12775 1676 4832 19283 4b53 cgroup.oSigned-off-by Li Zefan <[email protected]>
I'm not sure that saving 38 bytes is worth the tiny slowdown this might introduce, but I guess it doesn't hurt much either way.
Paul
Quoted 7 lines · Li Zefan
It's not small enough, and has 2 call sites.
text data bss dec hex filename 12813 1676 4832 19321 4b79 cgroup.o.orig 12775 1676 4832 19283 4b53 cgroup.oSigned-off-by Li Zefan <[email protected]>
I'm not sure that saving 38 bytes is worth the tiny slowdown this might introduce, but I guess it doesn't hurt much either way.
Paul